"A very simple short module containing useful functions"


What's new in version 1.6.1-> Corrected some color values

What's new in version 1.7.1-> Added transform_color function and updated documentation.

What's new in version 1.7.2-> Fixed shutil module import error

What's new in version 1.8.0-> Changed remove_dir(path) function to delete(path).

What's new in version 1.8.1-> Fixed is_Folder(path) function, and added is_File(path) function.

What's new in version 1.8.2-> Fixed get_foldername(path) and get_filename(path).

What's new in version 1.9.0-> Fixed get_startup_path() function

What's new in version 1.9.2-> Removed some unecessary print staements

What's new in version 1.9.2-> Fixed some bugs

What's new in version 1.9.3-> Added convert_currency function, which works on forex_python module